

# The SWC-DB Python Package

The Python modules for working with [SWC-DB](https://www.swcdb.org).



**Documentations are available at:**

* https://www.swcdb.org/use/thriftclient/python/

* https://kashirin-alex.github.io/swc-db/use/thriftclient/python/

